@@ -1,12 +1,12 @@
 package WordList::ID::Common::Wikipedia5000;
 
 our $DATE = '2020-10-11'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contain_nonword_chars",0,"num_words_contain_unicode",0,"num_words_contains_unicode",0,"num_words",5000,"num_words_contains_nonword_chars",0,"avg_word_len",7.4528,"shortest_word_len",2,"num_words_contains_whitespace",0,"num_words_contain_whitespace",0,"longest_word_len",18); # STATS
+our %STATS = ("num_words_contains_whitespace",0,"num_words_contains_nonword_chars",0,"avg_word_len",7.4528,"longest_word_len",18,"num_words_contains_unicode",0,"num_words_contain_unicode",0,"num_words_contain_whitespace",0,"shortest_word_len",2,"num_words_contain_nonword_chars",0,"num_words",5000); # STATS
 
 1;
 # ABSTRACT: Top 5000 words from Wikipedia Indonesia pages
@@ -21,7 +21,7 @@ WordList::ID::Common::Wikipedia5000 - Top 5000 words from Wikipedia Indonesia pa
 
 =head1 VERSION
 
-This document describes version 0.005 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2020-10-11.
+This document describes version 0.006 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2020-10-11.
 
 =head1 SYNOPSIS
 
